abacusai.video_gen_costs — AbacusAI documentation

# abacusai.video_gen_costs

## Classes

`VideoGenCosts` | The most expensive price for each video gen model in credits

## Module Contents

class abacusai.video_gen_costs.VideoGenCosts(client, modelCosts=None, expensiveModels=None, warningMessages=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  The most expensive price for each video gen model in credits

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - modelCosts (dict) – The costs of the video gen models in credits

    - expensiveModels (list) – The list of video gen models that are expensive

    - warningMessages (dict) – The warning messages for certain video gen models

  model_costs = None
  expensive_models = None
  warning_messages = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict